summaryrefslogtreecommitdiffstats
path: root/sync/internal_api/public/engine/model_safe_worker.h
diff options
context:
space:
mode:
Diffstat (limited to 'sync/internal_api/public/engine/model_safe_worker.h')
-rw-r--r--sync/internal_api/public/engine/model_safe_worker.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/sync/internal_api/public/engine/model_safe_worker.h b/sync/internal_api/public/engine/model_safe_worker.h
index d67f4b6..d76ddb9 100644
--- a/sync/internal_api/public/engine/model_safe_worker.h
+++ b/sync/internal_api/public/engine/model_safe_worker.h
@@ -13,7 +13,7 @@
#include "base/memory/ref_counted.h"
#include "sync/base/sync_export.h"
#include "sync/internal_api/public/base/model_type.h"
-#include "sync/internal_api/public/base/model_type_payload_map.h"
+#include "sync/internal_api/public/base/model_type_state_map.h"
#include "sync/internal_api/public/util/syncer_error.h"
namespace base {
@@ -80,9 +80,9 @@ base::DictionaryValue* ModelSafeRoutingInfoToValue(
SYNC_EXPORT std::string ModelSafeRoutingInfoToString(
const ModelSafeRoutingInfo& routing_info);
// Make a ModelTypePayloadMap for all the enabled types in a
// ModelSafeRoutingInfo using a default payload.
-ModelTypePayloadMap ModelSafeRoutingInfoToPayloadMap(
+ModelTypeStateMap ModelSafeRoutingInfoToStateMap(
const ModelSafeRoutingInfo& routes,
const std::string& payload);
@@ -80,9 +80,9 @@ base::DictionaryValue* ModelSafeRoutingInfoToValue(
SYNC_EXPORT std::string ModelSafeRoutingInfoToString(
const ModelSafeRoutingInfo& routing_info);
-// Make a ModelTypePayloadMap for all the enabled types in a
+// Make a ModelTypeStateMap for all the enabled types in a
// ModelSafeRoutingInfo using a default payload.